@@ -5,7 +5,7 @@ from __future__ import annotations
 import asyncio
 import logging
 import platform
-from typing import Any, Coroutine, Iterable
+from typing import Any, Coroutine, Iterable, no_type_check
 
 import async_interrupt
 import bleak
@@ -35,8 +35,12 @@ IS_LINUX = SYSTEM == "Linux"
 IS_MACOS = SYSTEM == "Darwin"
 
 if IS_LINUX:
-    from bleak.backends.bluezdbus.advertisement_monitor import OrPattern
+    from bleak.backends.bluezdbus.advertisement_monitor import (
+        AdvertisementMonitor,
+        OrPattern,
+    )
     from bleak.backends.bluezdbus.scanner import BlueZScannerArgs
+    from dbus_fast.service import method
 
     # or_patterns is a workaround for the fact that passive scanning
     # needs at least one matcher to be set. The below matcher
@@ -49,6 +53,21 @@ if IS_LINUX:
         ]
     )
 
+    class HaAdvertisementMonitor(AdvertisementMonitor):
+        """Implementation of the org.bluez.AdvertisementMonitor1 D-Bus interface."""
+
+        @method()
+        @no_type_check
+        def DeviceFound(self, device: "o"):  # noqa: UP037, F821
+            """Device found."""
+
+        @method()
+        @no_type_check
+        def DeviceLost(self, device: "o"):  # noqa: UP037, F821
+            """Device lost."""
+
+    AdvertisementMonitor.DeviceFound = HaAdvertisementMonitor.DeviceFound
+    AdvertisementMonitor.DeviceLost = HaAdvertisementMonitor.DeviceLost
 
 OriginalBleakScanner = bleak.BleakScanner
 
